lineage package
===============

Submodules
----------

lineage\.ensembl module
-----------------------

.. automodule:: lineage.ensembl
    :members:
    :undoc-members:
    :show-inheritance:

lineage\.individual module
--------------------------

.. automodule:: lineage.individual
    :members:
    :undoc-members:
    :show-inheritance:

lineage\.resources module
-------------------------

.. automodule:: lineage.resources
    :members:
    :undoc-members:
    :show-inheritance:

lineage\.visualization module
-----------------------------

.. automodule:: lineage.visualization
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: lineage
    :members:
    :undoc-members:
    :show-inheritance:
